@@ -131,6 +131,56 @@ to_rtf.hyperlink_ftext <- function(x, ...) {
     str_encode_to_rtf(x$value)
   )
 }
+rtf_bookmark <- function(id, str) {
+  bm_start_str <- sprintf("{\\*\\bkmkstart %s}", id)
+  bm_start_end <- sprintf("{\\*\\bkmkend %s}", id)
+  paste0(bm_start_str, str, bm_start_end)
+}
+
+#' @export
+to_rtf.run_autonum <- function(x, ...) {
+  if(is.null(x$seq_id)) return("")
+
+  run_str_pre <- to_rtf(ftext(x$pre_label, prop = x$pr))
+  run_str_post <- to_rtf(ftext(x$post_label, prop = x$pr))
+
+  seq_str <- paste0("SEQ ", x$seq_id, " \\\\* Arabic")
+  if(!is.null(x$start_at) && is.numeric(x$start_at)){
+    seq_str <- paste(seq_str, "\\r", as.integer(x$start_at))
+  }
+
+  sqf <- run_word_field(field = seq_str, prop = x$pr)
+  sf_str <- to_rtf(sqf)
+
+  if(x$tnd > 0){
+    z <- paste0(
+      to_rtf(run_word_field(field = paste0("STYLEREF ", x$tnd, " \\r"), prop = x$pr)),
+      to_rtf(ftext(x$tns, prop = x$pr))
+    )
+    sf_str <- paste0(z, sf_str)
+  }
+
+  if(!is.null(x$bookmark)){
+    if(x$bookmark_all){
+      out <- paste0(
+        rtf_bookmark(id = x$bookmark, str = paste0(run_str_pre, sf_str)),
+        run_str_post)
+    } else {
+      sf_str <- rtf_bookmark(id = x$bookmark, sf_str)
+      out <- paste0(run_str_pre, sf_str, run_str_post)
+    }
+  } else {
+    out <- paste0(run_str_pre, sf_str, run_str_post)
+  }
+
+  out
+}
+
+#' @export
+to_rtf.run_reference <- function(x, ...) {
+  out <- to_rtf(run_word_field(field = paste0(" REF ", x$id, " \\\\h "), prop = x$pr))
+  out
+}
 
 ## to_rtf sections ----
 
@@ -224,6 +274,7 @@ guess_hfr_type <- function(x) {
   }
 }
 
+#' @export
 to_rtf.page_mar <- function(x, ...) {
   sprintf(
     "\\margb%.0f\\margt%.0f\\margr%.0f\\margl%.0f\\gutter%.0f\\headery%.0f\\footery%.0f",
@@ -636,7 +687,7 @@ rtf_add.gg <- function(x, value, width = 6, height = 5, res = 300, scale = 1, pp
   }
 
   file <- tempfile(fileext = ".png")
-  png(filename = file, width = width * scale, height = height * scale, units = "in", res = res, ...)
+  agg_png(filename = file, width = width, height = height, units = "in", res = res, scaling = scale, background = "transparent", ...)
   tryCatch(
     {
       print(value)
@@ -658,7 +709,7 @@ rtf_add.gg <- function(x, value, width = 6, height = 5, res = 300, scale = 1, pp
 #' @describeIn rtf_add add a [plot_instr()] object
 rtf_add.plot_instr <- function(x, value, width = 6, height = 5, res = 300, scale = 1, ppr = fp_par(text.align = "center"), ...) {
   file <- tempfile(fileext = ".png")
-  png(filename = file, width = width * scale, height = height * scale, units = "in", res = res, ...)
+  agg_png(filename = file, width = width, height = height, units = "in", res = res, scaling = scale, background = "transparent", ...)
   tryCatch(
     {
       eval(value$code)
@@ -762,7 +813,7 @@ str_encode_to_rtf <- function(z) {
       is_tobeprotected <- charv %in% c("\\", "{", "}")
       # is_std_ansi <- intv < 128
       # is_ext_ansi <- !is_std_ansi & intv < 256
-      is_ext_ansi <- intv < 256
+      is_ext_ansi <- intv < 128
       is_unic2b <- !is_ext_ansi & intv < 32768
       is_unic4b <- !is_ext_ansi & !is_unic2b
       charv[is_unic2b] <- paste0("\\uc1\\u", intv[is_unic2b], "?")
